package shallow_shared_workspace

import (
	"encoding/json"

	"cloud.o-forge.io/core/oc-lib/models/utils"
	"cloud.o-forge.io/core/oc-lib/tools"
	"github.com/google/uuid"
)

type ShallowSharedWorkspace struct {
	utils.AbstractObject
	IsSent      bool                   `json:"is_sent" bson:"-"`
	CreatorID   string                 `json:"peer_id,omitempty" bson:"peer_id,omitempty" validate:"required"`
	Version     string                 `json:"version,omitempty" bson:"version,omitempty"`
	Description string                 `json:"description,omitempty" bson:"description,omitempty" validate:"required"`
	Attributes  map[string]interface{} `json:"attributes,omitempty" bson:"attributes,omitempty"`
	Workspaces  []string               `json:"workspaces,omitempty" bson:"workspaces,omitempty"`
	Workflows   []string               `json:"workflows,omitempty" bson:"workflows,omitempty"`
	Peers       []string               `json:"peers,omitempty" bson:"peers,omitempty"`
	Rules       []string               `json:"rules,omitempty" bson:"rules,omitempty"`
}

func (ao *ShallowSharedWorkspace) GetID() string {
	return ao.UUID
}

func (r *ShallowSharedWorkspace) GenerateID() {
	if r.UUID == "" {
		r.UUID = uuid.New().String()
	}
}

func (d *ShallowSharedWorkspace) GetName() string {
	return d.Name
}

func (d *ShallowSharedWorkspace) GetAccessor(caller *tools.HTTPCaller) utils.Accessor {
	data := New()
	data.Init(utils.SHARED_WORKSPACE, caller)
	return data
}

func (dma *ShallowSharedWorkspace) Deserialize(j map[string]interface{}) utils.DBObject {
	b, err := json.Marshal(j)
	if err != nil {
		return nil
	}
	json.Unmarshal(b, dma)
	return dma
}

func (dma *ShallowSharedWorkspace) Serialize() map[string]interface{} {
	var m map[string]interface{}
	b, err := json.Marshal(dma)
	if err != nil {
		return nil
	}
	json.Unmarshal(b, &m)
	return m
}
